@@ -379,5 +379,23 @@ class domonicTestCase(unittest.TestCase):
         pass
 
 
+    def test_javascript_interval(self):
+
+        def hi():
+            print('hi')
+            pass
+
+        test = window.setInterval( 0.1, hi )
+        print('im going to do some stuff in the background')
+        
+        # keep the test open to see if the intervals fire
+        import time
+        time.sleep(5)
+        
+        print('running')
+        window.clearInterval(test)
+        print('ran')
+
+
 if __name__ == '__main__':
     unittest.main()
